//
//  View.m
//  Accelerometer
//
//  Created by NYU User on 10/11/10.
//  Copyright 2010 __MyCompanyName__. All rights reserved.
//

#import "View.h"


@implementation View


- (id) initWithFrame: (CGRect) frame {
	if ((self = [super initWithFrame: frame]) != nil) {
		// Initialization code
		self.backgroundColor = [UIColor whiteColor];

		accelerometer = [UIAccelerometer sharedAccelerometer];
		double hertz = 10;	//cycles per second
		accelerometer.updateInterval = 1.0 / hertz;
		accelerometer.delegate = self;	//accelerometer now active
		
	}
	return self;
}


// Only override drawRect: if you perform custom drawing.
// An empty implementation adversely affects performance during animation.
- (void) drawRect: (CGRect) rect {
	// Drawing code
	UIFont *f = [UIFont systemFontOfSize: 20];
	CGPoint p = CGPointMake(5, 0);
	
	NSString *s = [NSString stringWithFormat: @"x == %f", x];
	[s drawAtPoint: p withFont: f];
	p.y += [s sizeWithFont: f].height;	//Move down one line.
	
	s = [NSString stringWithFormat: @"y == %f", y];
	[s drawAtPoint: p withFont: f];
	p.y += [s sizeWithFont: f].height;
	
	s = [NSString stringWithFormat: @"z == %f", z];
	[s drawAtPoint: p withFont: f];
	
	if (x != 0 || y != 0) {
		p.y += [s sizeWithFont: f].height;
		//degrees counterclockwise from 3 o'clock
		s = [NSString stringWithFormat: @"θ == %f°",
			 atan2(y, x) * 180 / M_PI];
		[s drawAtPoint: p withFont: f];
	}
	
	//Put the origin at the center.
	CGContextRef c = UIGraphicsGetCurrentContext();
	CGSize size = self.bounds.size;
	CGContextTranslateCTM(c, size.width / 2, size.height / 2);
	
	//X axis
	CGContextBeginPath(c);	//documentation only
	CGContextMoveToPoint(c, -size.width / 2, 0);
	CGContextAddLineToPoint(c, size.width / 2, 0);
	
	//Y axis
	CGContextMoveToPoint(c, 0, size.height / 2);
	CGContextAddLineToPoint(c, 0, -size.height / 2);

	int gForces = 3;	//show up to this many G forces
	CGFloat width = 2 * gForces;

	CGFloat scale = size.width / width;
	CGContextConcatCTM(c, CGAffineTransformMakeScale(scale, -scale));
			
	CGContextSetRGBStrokeColor(c, 0, 0, 1, 0.5);	//faint blue
	CGContextSetLineWidth(c, 1.0 / scale);
	CGContextStrokePath(c);

	//Draw the gravity vector.
	CGContextBeginPath(c);	//documentation only
	CGContextMoveToPoint(c, 0, 0);
	CGContextAddLineToPoint(c, x, y);

	CGContextSetRGBStrokeColor(c, 0.0, 0.0, 0.0, 1.0);	//black
	CGContextStrokePath(c);
}

- (void) dealloc {
	[super dealloc];
}

#pragma mark -
#pragma mark method of protocol UIAccelerometerDelegate

- (void) accelerometer: (UIAccelerometer *) accelerometer
	didAccelerate: (UIAcceleration *) acceleration {
	x = acceleration.x;
	y = acceleration.y;
	z = acceleration.z;
	[self setNeedsDisplay];
}


@end
